

** 03/19/2013: OSU COMPARATIVE EFFECTIVENESS RESEARCH TRAINING PROGRAM

** ANALYSIS OF HCUP DATA USING STATA: A Step-by-Step example
** Brook I. Martin, PhD
** Geisel School of Medicine at Dartmouth
** Dartmouth-Hitchcock Medical Center

/* 
NOTES TO USERS:  
1) The data provided for this worked example represents a small, non=randonly selected subset of the 
actual data in from the respective HCUP database.  It is intended for educational training only and 
should not be used to represent an actual analysis for policy or pulication.

2) There are multiple ways to perform analysis in Stata.  I chose to provde the approach that I am 
most familiar and use regularly.  Results may have slight differences based on the statistical method 
or Stata version.

3) I love to get constructive feedback about how useful (or not) this presentation is, please feel free
email me with your questions, clarifications, or suggestions to improve.  Brook.I.Martin@Dartmouth.edu
*/


*************************************************************
****************** HIP SAMPLE DATA CODING & COMBINING *******
*************************************************************

* read data into Stata  This data already combines multiple years of data
use "I:\DATA\NIS\NIS_0109_Core_1pct.dta", clear  // if data is already a Stata data file
count
tab YEAR

** CLEAN UP ICD-9 PROCEDURE CODES ****
foreach num of numlist 1(1)15{	// use loop to clean all procedure fields
icd9p check PR`num', gen(tag`num')		
replace PR`num' = "" if tag`num' > 0	// cleans up unrecognized codes
drop tag*			// cleans up temporary varaibles used to clear procedure codes
}


* METHOD #1: SIMPLE SELCETION ONLY LOOKS AT FIRST CODED PROCEDURE
preserve								// I use preserve and restore to run a command and then return to the original data
icd9p generate keep = PR1, range(81.51)	// select total hip repair
tab keep 
drop if keep == 0
count 
tab YEAR
restore

* METHOD #2 COMPLEX SELECTION BY LOOPING OVER ALL PROCEDURES FIELDS AND MULTIPLE CODES.
preserve
foreach num of numlist 1(1)15{
qui icd9p generate temp`num' = PR`num', range(81.51 81.52 0070 0071 0072 0073 8153)  // Multiple field + revision procedures
}
egen keep = anymatch(temp*), values(1) 
tab keep 
drop if keep == 0
count 
tab YEAR
restore



* METHOD #3 APPLY CODING ALGORITHM - ALLOWS MORE FLEIXBILITY IN CONDITIONAL CODES, INCLUSION OF DIAGNOSIS CODES, MORE DEFINITIONS.
preserve
*do "I:\DATA\ALGORITHM\HIPCODE\HipDef.do"  // You do not have this file, so the ccommand will not run; I've run it for you and provided a file
hipdef DX1.dx DX2.dx DX3.dx DX4.dx DX5.dx DX6.dx DX7.dx DX8.dx DX9.dx DX10.dx DX11.dx DX12.dx  ///
DX13.dx DX14.dx DX15.dx DX16.dx DX17.dx DX18.dx DX19.dx DX20.dx DX21.dx DX22.dx DX23.dx DX24.dx DX25.dx ///
PR1.sx PR2.sx PR3.sx PR4.sx PR5.sx PR6.sx PR7.sx PR8.sx PR9.sx PR10.sx PR11.sx PR12.sx PR13.sx PR14.sx PR15.sx
tab HPTX7 HPTX8 // variable created to identify partial or total hip replacements
keep if ANYHIP
tab HPSEV
tab HPSEV HPTX7, col
count 
tab YEAR
count if HPTX7 == 1 | HPTX8 == 1
save "I:\OSU\HCUP_StepbyStep\HipSource.dta", replace
restore


*************************************************************
****************** HIP SAMPLE DATA CLEANING *****************
*************************************************************
capture log close
log using OSUmodule, replace
version 12
clear all 
macro drop _all
set linesize 80


** LOAD DATA FOR NIS HIP PROCEDURES FROM 2001- 2009
use "I:\OSU\HCUP_StepbyStep\HipSource.dta", clear
count


** CREATE GROUPED AGE VARIABLE.  THE GROUPS CREATED HERE ARE CONSISTENT WITH U.S. AGE GROUP DATA.
** THE VARIABLE AGEc retains the continuous version of AGE
gen AGEc = AGE
hist AGEc
recode AGE (. = .) (min/1 = 0) (1/4 = 1) (5/9 = 2) (10/14 = 3) (15/19 = 4) (20/24 = 5) (25/29 = 6) (30/34 = 7)(35/39 = 8)(40/44 = 9)(45/49 = 10) ///
(50/54 = 11)(55/59 = 12)(60/64 = 13)(65/69 = 14)(70/74 = 15)(75/79 = 16)(80/84 = 17)(85/max = 18) 
tab AGE, miss

 * CREATE A POLYNOMIAL VARIABLE FOR AGE THAT MIGHT BE USEFUL IN SOME MODELS
gen AGE2 = AGEc*AGEc 

* CREATE DICHOTOMOUS VARIABLE FOR AGE (+/- 65 YEAR) FOR SOME PRESENTATIONS
gen AGEdi = .
replace AGEdi = 0 if AGEc < 65
replace AGEdi = 1 if AGEc >= 65


* IN NIS, THE VARIABLE NAME AND CODING FOR THE MEDIAN INCOME OF THE PATIENTS AREA CODE,
* A SOCIOECONOMIC INDICATOR, DIFFERS BY YEAR.  WHEN COMBINING MULTIPLE YEARS, IT IS NECESSARY 
* TO RECONCILE SOME VARIABLES THE HAVE CODING OR DEFINITION CHANGES.  IN SOME CASES THE IT MAY 
* NOT BE POSSIBLE TO RECONCILE ACROSS YEARS.  (E.g. Coding of ZIP_INC in 2001-2002 IS VERY DIFFERENT 
* THAN SUBSEQUENT YEARS (REFER TO ONLINE CODEBOOK).
tab ZIPINC YEAR // 2001-2002  DO NOT RECODE THIS- THE CODING DIFFERS FROM THAT OF SUBSEQUENT YEARS.
tab ZIPInc_Q YEAR  // 2003-2004
tab ZIPInc_Qrtl YEAR // 2005
tab ZIPINC_QRTL YEAR // 2006-2009
replace ZIPINC_QRTL = ZIPInc_Q if YEAR == 2003 | YEAR == 2004	// update the ZIPINC_QRTL with values from earlier years
replace ZIPINC_QRTL = ZIPInc_Qrtl if YEAR == 2005 				// update the ZIPINC_QRTL with values from earlier years
drop ZIPInc_Q ZIPInc_Qrtl   // Clean up data by removing variables that I don't need any more

* CLEAN UP COMPLEX SURVEY STRATUM VARIABLE WHERE THE VARIABLE NAME CHANGES IN DIFFERENT YEARS.
replace NIS_STRA = NIS_STRATUM  if NIS_STRA == .
drop NIS_STRATUM

* GENERATE EXCLUSION VARIABLE TO INDICATE THOSE YOUNGER THAN AGE 20 (AGE variables <= 4
gen TOOYOUNG = .
replace TOOYOUNG = 0
replace TOOYOUNG = 1 if AGE <=4  // AGE CATEGORY is less than or equal 4 = under 20 years.


* NIS CONTAINS A VARIABLE FOR ELECTIVE PROCEDURES: FOR THIS PARTICULAR STUDY I WANT TO 
* ONLY INCLUDE THOSE WITH ELECTIVE TOTAL HIP REPLACEMENT
gen NONELECTIVE = .
replace NONELECTIVE = 0 
replace NONELECTIVE = 1 if ELECTIVE == 0 

* SIMPLIFY THE CODING OF RACE/ETHNICITY VARIABLE BY COMBINING GROUPS (NOT THE HIGH DEGREE OF MISSING)
generate RACE1 = .
replace RACE1 = 1 if (RACE == 1)
replace RACE1 = 2 if (RACE == 2)
replace RACE1 = 3 if (RACE == 3) 
replace RACE1 = 4 if (RACE == 4) | (RACE == 5) | (RACE == 6)
label variable RACE1 "Race recoded"
label define racerelbl 1 "White" 2"Black" 3"Hispanic" 4"Other"
label values RACE1 racerelbl
tab RACE1 YEAR, col chi2 miss

* MAKE VARIABLE TO PRIMARY PAYER RECODED
gen PAY_1 = PAY1
recode PAY_1  (1=1) (2=2) (3=3) (4/6=4)
label variable PAY_1 "Payer recoded"
label define paylbl 1"Medicare" 2"Medicaid" 3"Private" 4"Other"
label values PAY_1 paylbl
tab PAY_1 YEAR, col chi2

* CONVERT TOTAL CHARGES TO 2009 EQUIVALENTS REFERENCING MEDICAL SERVICE COMPONENT OF CPI
* FROM U.S. BUREAU OF LABOR STATISTICS: Labor Series ID CUUS0000SAM2
replace TOTCHG = TOTCHG*1.42503 if YEAR == 2001
replace TOTCHG = TOTCHG*1.35643 if YEAR == 2002
replace TOTCHG = TOTCHG*1.29836 if YEAR == 2003
replace TOTCHG = TOTCHG*1.23654 if YEAR == 2004
replace TOTCHG = TOTCHG*1.17998 if YEAR == 2005
replace TOTCHG = TOTCHG*1.1332 if YEAR == 2006
replace TOTCHG = TOTCHG*1.07581 if YEAR == 2007
replace TOTCHG = TOTCHG*1.0321 if YEAR == 2008
replace TOTCHG = TOTCHG*1 if YEAR == 2009

** IMPORT NIS COST TO CHARGE RATIO FOR HOSPITAL AND APPLY TO CHARGES
count
rename HOSPID hospid  // THE VARIABLE NAMES BETWEEN THE USING AND MASTER FILES OF A MERGE MUST BE IDENTICAL AND ARE CASE SENSITIVE
rename YEAR year
merge m:1 year hospid using "I:\OSU\HCUP_StepbyStep\NIS_CCR.dta", keepusing(gapicc) update replace  // A MANY TO ONE MERGE MATCHING BY HOSPITAL AND YEAR
keep if _merge == 3 | _merge == 1 |_merge == 4
drop _merge
count

* EXAMINE HOW MANY CASES HAVE MISSING CCR
count if gapicc == .

*REPLACE THE MISSING CCR RECORDS WITH THE MEAN FOR THOSE THAT HAVE MISSINGNESS- A SIMPLE IMPUTATION METHOD
summarize gapicc
replace gapicc = r(mean) if gapicc == .  // NOTE THE "r(mean)" is a stored value that is created in Stata memory from the previous summarize command.

*GENERATE A COST VARIABLE BY MULTIPLY THE CCR TO TOTAL CHARGES
generate COST = TOTCHG * gapicc
rename year YEAR

* CALCULATE CHARLSON COMORBIDTY INDEX USING COMMAND BUILT INTO STATA  * See "help charlson" for details
charlson DX1 DX2 DX3 DX4 DX5 DX6 DX7 DX8 DX9 DX10 DX11 DX12 DX13 DX14 /// 
DX15 DX16 DX17 DX18 DX19 DX20 DX21 DX22 DX23 DX24 DX25  , icd(9enh) assign0 wtchrl cmorb  

* RECODE ONE OF THE DIAGNOSIS VARIABLES FROM MY CODING TEMPLATE INTO SIMPLIER GROUPS
gen HPSEV2 = HPSEV
recode HPSEV2 (3 = 1) (7 = 2) (1/2 = 3) (4/6 = 3) (8/max = 3)
label define HPSEV2 1"Osteoarthritis" 2"Avascular necrosis" 3"Other"
label values HPSEV2 HPSEV2
tab HPSEV2

* MAKE CATEGORICAL VARIABLE FOR LENGTH OF STAY
gen LOSGRP = .
replace LOSGRP = 0 if LOS <=1
replace LOSGRP = 1 if LOS == 2
replace LOSGRP = 2 if LOS == 3
replace LOSGRP = 3 if LOS == 4
replace LOSGRP = 4 if LOS >= 5

* CREATE INDICATOR FOR HAVING EITHER PE OR DVT  (CODE SPECIFIC TO THIS PROJECT)
egen PEDVT = anymatch(HPPSI6 HPPSI7), values(1)
tab PEDVT , miss

* CREATE INDICATOR FOR ANY OF THE COMPLICATIONS THAT WE INCLUDED IN OUR CODING TEMPLATE
egen ANYPSI = anymatch(HPPSI*), values(1)
tab ANYPSI , miss

save "I:\OSU\HCUP_StepbyStep\HipAnalysis.dta", replace


log close
exit

**********************************************************************************************
********************** ANALYSIS SECTION   ****************************************************
**********************************************************************************************
capture log close
log using OSU_HCUP_ANALYSIS, replace
version 12
clear all 
macro drop _all
set linesize 80

use "I:\OSU\HCUP_StepbyStep\HipAnalysis.dta", clear

/*
NOTE - BECAUSE THIS IS A RESTRICTIVE SUBSAMPLE FOR EDUCATIONAL PURPOSES ONLY, THE ESTIMATES 
AND ANALYSES WILL NOT REFLECT THE TRUE POPULATION.
IN COMPLEX SURVEY ANALYSIS YOU DO NOT WANT DROP CASES - INSTEAD YOU INCLUDE EXCLUSION CRITERIA
IN THE "SUBPOP" OPTION OF THE SVY COMMAND
*/

* TELL STATA THAT THE DATA SET DERIVES FROM COMPLEX SURVEY DATA AND SPECIFY THE DESIGN VARIABLES 
gen pt = 1
gen id = _n
svyset id [pw=DISCWT], strata(NIS_STRA) singleunit(centered)

** FOR SIMPLE DESCRIPTIVE STATISTICS ROUND THE PATIENT WEIGHT VARIABLE
gen DISCWTR = round(DISCWT) 

* COUNT BY YEAR
tab YEAR
tab YEAR [freq = DISCWTR]

**********************************************************************************************
********************** INCLUSION CRITERIA ****************************************************
**********************************************************************************************

* USING THE VARIABLES THAT WE CREATED BY APPLYING CODING TEMPLATE 
* IDENTIFY THE COMBINATION OF DIAGNOSIS VARAIBLES THAT YOU WANT TO INCLUDE
* CREATE VARIABLE CALLED "INdiag" TO SELECT PATIENTS MEETING THIS CRITERIA
* EXAMPLE: IN THIS STUDY WE DO NOT WANT TO LIMIT SELECTION OF PATIENT BASED ON HIP DIAGNOSIS AT THIS STEP
tabstat  HPDX1 HPDX2 HPDX3 HPDX4 HPDX5 HPDX6 HPDX7 HPDX8 HPDX9 HPDX10 HPDX11, stat(mean sum count) col(stat) 
egen INdiag = anymatch(HPDX1 HPDX2 HPDX3 HPDX4 HPDX5 HPDX6 HPDX7 HPDX8 HPDX9 HPDX10 HPDX11), values(1)    // IN THIS EXAMPLE WE DO NOT WANT TO LIMIT SELECTION OF PATIENT BY DIANGOSIS ALL DX's ARE INCLUDED
tab INdiag

* USING THE VARIABLES THAT WE CREATED BY APPLYING CODING TEMPLATE 
* IDENTIFY THE COMBINATION OF PROCEDURE VARAIBLES THAT YOU WANT TO INCLUDE
* CREATE VARIABLE CALLED "INproc" TO SELECT PATIENTS MEETING THIS CRITERIA

tabstat  HPTX1 HPTX2 HPTX3 HPTX4 HPTX5 HPTX6 HPTX7 HPTX8 , stat(mean sum count) col(stat)
egen INproc = anymatch(HPTX7), values(1)  	// IN THIS EXAMPLE WE ONLY WANT TO SELECT PATIENT WITH A TOTAL HIP REPLACEMENT (HPTX7 == 1)
tab INproc

* SUMMARIZE INCLUSION
gen ALLIN = 0 
replace ALLIN = 1 if INproc ==1 & INdiag == 1
tab ALLIN
keep if ALLIN == 1		// AFTER SUMMARIZING - RESTRICT SUBSEQUENT ANALYSIS TO INCLUDED COHORT BY DROPPING THOSE WHO DO NOT MEET CRITERIA
count

**********************************************************************************************
********************** EXCLUSION CRITERIA ****************************************************
**********************************************************************************************

* USING THE VARIABLES THAT WE CREATED BY APPLYING CODING TEMPLATE 
* IDENTIFY THE COMBINATION OF VARAIBLES THAT DEFINE AN EXCLUSION

* CREATE VARIABLE CALLED "EXdiag" TO IDENTIFY PATIENTS WHO HAVE A DIAGNOSIS EXCLUSION 
* IN THIS EXAMPLE WE WANT TO EXCLUDE PATIENTS WITH OSTEOPOROSIS (HPDX5 = 1), HIP FRACTURE (HPDX10 = 1), REVISIONS (HPDX11 = 1)
tabstat  HPDX1 HPDX2 HPDX3 HPDX4 HPDX5 HPDX6 HPDX7 HPDX8 HPDX9 HPDX10 HPDX11, stat(mean sum count) col(stat)  
egen EXdiag = anymatch(HPDX5 HPDX10 HPDX11), values(1)		// CREATE SUMMARY VARAIBLE FOR EXCLUSIONS BASED ON DiAGNOSIS

* CREATE VARIABLE CALLED "EXproc" TO IDENTIFY PATIENTS WHO HAVE A PROCEDURE EXCLUSION 
* IN THIS EXAMPLE WE WANT TO EXCLUDE PATIENTS WHO ALSO HAVE FRACTURE TREATMENT (HPTX3 = 1), REDUCTION OF THA (HPTX4 = 1), OTHER HIP PROCEDURES (HPTX5 = 1), TENOTOMY (HPTX6 = 1), PARTIAL HIP (HPTX7 = 1)
tabstat  HPTX1 HPTX2 HPTX3 HPTX4 HPTX5 HPTX6 HPTX7 HPTX8, stat(mean sum count) col(stat)
egen EXproc = anymatch(HPTX3 HPTX4 HPTX5 HPTX6 HPTX8 ), values(1)

* * CREATE VARIABLE CALLED "EXcomorb" TO IDENTIFY PATIENTS WHO HAVE A COMORBIDITY EXCLUSION 
tabstat ynch1 ynch2 ynch3 ynch4 ynch5 ynch6 ynch7 ynch8 ynch9 ynch10 ynch11 ynch12 ynch13 ynch14 ynch15 ynch16 ynch17, stat(mean sum count) col(stat)
egen EXcomorb = anymatch(ynch16 ynch14 ynch17), values(1)  // CREATE VARIABLE TO EXCLUDE PATIENTS WITH AIDS (ynch17 = 1), CANCER (ynch14 & ynch16 = 1)

* MISCELLANEOUS EXCLUSIONS 
tabstat TOOYOUNG NONELECTIVE, stat(mean sum count) col(stat)
egen EXother = anymatch(TOOYOUNG NONELECTIVE), values(1)  // summary variable to exclude patients who are under age 20, or having non-elective hip surgery

** SUMMARIZE EXCLUSIONS
tabstat EXdiag EXproc EXcomorb EXother, stat(mean sum count) col(stat)
egen ANYEX = anymatch(EXdiag EXproc EXcomorb EXother), values(1)   // VARIABLE FOR ANY EXCLUSION THIS WILL BE USED IN PRIMARY ANALYSIS

* SUMMARY OF UNWEIGHTED EXCLUSIONS
tabstat HPDX5 HPDX10 HPDX11 HPTX3 HPTX4 HPTX5 HPTX6 HPTX8 ynch16 ynch14 ynch17 EXdiag EXproc EXcomorb EXother TOOYOUNG NONELECTIVE , stat(sum mean count) column(stat)
tab ANYEX 

* SUMMARY BASED ON WEIGHTED EXCLUSIONS
tabstat HPDX5 HPDX10 HPDX11 HPTX3 HPTX4 HPTX5 HPTX6 HPTX8 ynch16 ynch14 ynch17 EXdiag EXproc EXcomorb EXother TOOYOUNG NONELECTIVE [fw=  DISCWTR], stat(sum mean count) column(stat)

* SUMMARY ANY EXCLUSION
tab ANYEX [fw=  DISCWTR]

* COUNT OF FINAL COHORT AFTER EXCLUSION WEIGHTED AND UNWEIGHTED.
tab YEAR if ANYEX == 0
tab YEAR [fw=  DISCWTR] if ANYEX == 0


******************************************************************************
** REPORTING VOLUME, RATES AND TRENDS IN ADMISSIONS OR PROCEDURES        *****
******************************************************************************
* PROCEDURE VOLUME, STRATIFIED BY AGE +/- 65 years
preserve							 // preserve & restore because we collapse data, but want to return to original data
collapse (sum) DISCWTR if ANYEX == 0, by(YEAR AGEdi)  // collapse on Age grou and year
tabstat DISCWTR , by(YEAR) stat(sum) // overall volume by year
tabstat DISCWTR if AGEdi == 0, by(YEAR) stat(sum) // age by year, under 65
tabstat DISCWTR if AGEdi == 1, by(YEAR) stat(sum) // age by year, over 65
restore
* AGE & SEX ADJUSTED POPULATION RATES USING DIRECT STANDARDIZATION TO THE U.S. CENSUS
* THIS USES STATA'S COMMAND FOR DIRECT STANDARDIZATION.  THERE IS AN OPTION FOR INDIRECT
* STANDARDIZATION IN THE COMMAND, SEE "help dstdize"
* NOTE IN THE EXAMPLE DATA THE RATES DO NOT REFLECT REAL PRACTICE BECAUSE THIS ONLY REPRESENTS A SMALL SUBSET OF CASES
preserve
collapse (sum) DISCWTR if ANYEX == 0 , by(YEAR AGE FEMALE)		// collapse on strata the match to Census
merge 1:1 AGE FEMALE YEAR using "I:\OSU\HCUP_StepbyStep\USCIVPOP.dta", keepusing(POP) // import age/sex/year specific denominator
keep if _merge == 3 		// keep only relevant strata - note that missing age or sex will be dropped, thus lowering the rates.
gen AGEdi = 0				// recreated dichotomous age indicator
replace AGEdi = 1 if AGE >= 14
dstdize DISCWTR POP AGE FEMALE , by(YEAR)  // overall rates by year
dstdize DISCWTR POP AGE FEMALE if AGEdi == 0, by(YEAR) // age by over/under 65
dstdize DISCWTR POP AGE FEMALE if AGEdi == 1, by(YEAR) // age by over/under 65
restore


* USING POISSON REGRESSION MODEL TO REPORT INCIDENT RATE RATIO FOR AGE & SEX
* NOTE THAT THIS DOES NOT USE THE SURVEY COMMANDS, BUY IS WEIGHTED WITH COLLAPSE COMMAND.
preserve
collapse (sum) pt [fw = DISCWTR] if ANYEX == 0, by(YEAR AGE FEMALE)
merge 1:1 AGE FEMALE YEAR using "I:\OSU\HCUP_StepbyStep\USCIVPOP.dta", keepusing(POP) 
keep if _merge == 3
drop _merge
gen AGEdi = 0
replace AGEdi = 1 if AGE >= 14
tab AGE, gen(a)
tab YEAR , gen(y)
gen lnPOP = log(POP)
poisson pt i.YEAR i.a2 i.a3 i.a4 i.a5 i.a6 i.a7 i.a8 i.a9 i.a10 i.a11 i.a12 i.a13 i.a14 i.FEMALE , offset(lnPOP) irr
margins YEAR, at((means)_all ) over(AGEdi) expression((predict(ir)*100000))  // MARGINAL EFFECTS OF +/- AGE OVER 65  : THIS CAN SOMETIMES TAKE A LONG TIME IN BIG DATA SETS
marginsplot     // MARGINSPLOT ONLY WORKS WITH STATA VERSION 12 OR HIGHER.
* REMINDER THESE ESTIMATES DO NOT REFLECT REAL WORLD RATES BECAUSE THE DATA REPRESENT ONLY A SUBSET USED FOR EDUCATIONAL PURPOSES
restore

drop if YEAR == 2001  // because YEAR 2001 ELECTIVE surgery variables is not included 

**********************************************************************************************
********************** STATISTICAL ANALYSIS AND COMPARISONS      *****************************
**********************       BASED ON WEIGHTED SAMPLE            *****************************
**********************************************************************************************


/* DESCRIPTIVE STATITICS
THE FOLLOWING CODE SUMMARIZES DESCRIPTIVE STATISTICS OF PATIENT CHARACTERISTICS FOR TWO SELECT YEARS 
(2003 & 2009). IT PERFORMS CHI-SQUARE COMPARISONS OF THE FREQUENCY DISTRIBUTION BETWEEN THESE TWO 
YEARS BASED ON THE WEIGHTED SAMPLE (USING SVY COMMANDS)
THE ANALYSIS IS NESTED WITHIN "preserve" and "restore" COMMANDS BECAUSE I AM LIMITING THE ANALYSIS TO 
JUST THE TWO YEAR, BUT THEN WANT TO RETURN TO THE FULL DATA SET FOR THE REST OF THE ANALYSIS
PATIENTS WITH EXCLUSIONS ARE REMOVED USING THE SVY SUBPOP COMMAND
FINALLY, INSTEAD OF RERUNNING THE COMMAND FOR EACH VARIABLE OF INTEREST, I SIMPLE LIST THE VARIABLES
ONE TIME IN A "local" (TEMPORARY STORAGE) VARIABLE CALL "covars" AND THEN LOOP THROUGH THE COMMAND.
LOOPING IS AN EFFICIENT WAY OF REPEATING A COMMAND WITH WRITING A LOT OF CODE.
 */ 
preserve
keep if YEAR == 2003 | YEAR == 2009 							// LIMIT TO 2003 & 2009 FOR COMPARISON  (REMOVE LINE TO INCLUDE ALL YEARS)
svy linearized, subpop(if ANYEX == 0) : total pt , over(YEAR)						// COUNT OF PATIENTS
svy linearized, subpop(if ANYEX == 0) : mean AGEc							// MEAN AGE (CONTINOUS VARIABLE) FOR WHOLE COHORT
svy linearized, subpop(if ANYEX == 0) : mean AGEc, over(YEAR)				// MEAN AGE BY YEAR
svy linearized, subpop(if ANYEX == 0) : regress AGEc YEAR					// STATISTICAL TEST FOR DIFFERNCE IN AGE BY YEAR
local covars = " AGEdi FEMALE RACE1 charlindex ZIPINC_QRTL PAY_1 LOSGRP HPSEV2 "	// STORE LIST OF VARIABLES OF INTEREST AS COVARS
foreach v of local covars {										// LOOP THROUGH EACH VARIABLE IN COVAR
svy linearized: tabulate `v' YEAR  if ANYEX == 0 , col pearson  // AND TEST DIFFERNCE IN FREQUENCY BETWEEN TWO YEARS
}
restore

/* COSTS
THE FOLLOWING CODE SUMMARIZES BIVARIATE ASSOCIATIONS BETWEEN COVARIATES AND HOSPITAL COSTS.
IT PERFORMS A GENERALIZED LINEAR MODEL (GAMMA DISTRIBUTION LOG LINK) OF COSTS AS A FUNCTION 
OF EACH COVARIATE OF INTEREST BASED ON THE WEIGHTED SAMPLE (USING SVY COMMANDS)
PATIENTS WITH EXCLUSIONS ARE REMOVED USING THE SVY SUBPOP COMMAND
INSTEAD OF RERUNNING THE COMMAND FOR EACH VARIABLE OF INTEREST, I SIMPLE LIST THE VARIABLES
ONE TIME IN A "local" (TEMPORARY STORAGE) VARIABLE CALL "covars" AND THEN LOOP THROUGH THE COMMAND.
LOOPING IS AN EFFICIENT WAY OF REPEATING A COMMAND WITH WRITING A LOT OF CODE.
 */ 
svy linearized,  subpop(if ANYEX == 0) : mean COST 
local covars = "LOSGRP YEAR AGEdi FEMALE RACE1 charlindex ZIPINC_QRTL PAY_1 HPSEV2 PEDVT ANYPSI"
foreach v of local covars {
svy linearized,  subpop(if ANYEX == 0): glm COST i.`v' , family(gamma) link(log)  // GLM REGRESSION OF COSTS
margins `v'																		// MARGINAL COSTS FOR COVARIATE
}

*COSTS 
graph box COST if ANYEX == 0 [pweight = DISCWT], over(PEDVT) noout  // creating boc plots note whiskers are not 95% CI


/* 
THE FOLLOWING CODE USES A MULTIVARIABLE GLM REGRESSION TO EXAMINE THE ASSOCIATION 
BETWEEN COVARIATES AND HOSPITAL COSTS.  IT PERFORMS A GENERALIZED LINEAR MODEL (GAMMA DISTRIBUTION LOG LINK) 
OF COSTS AS A FUNCTION OF COVARIATES BASED ON THE WEIGHTED SAMPLE (USING SVY COMMANDS)
PATIENTS WITH EXCLUSIONS ARE REMOVED USING THE SVY SUBPOP COMMAND
LOOPING IS AN EFFICIENT WAY OF REPEATING A COMMAND WITH WRITING A LOT OF CODE.
 */ 
svy linearized, subpop(if ANYEX == 0): glm COST i.PEDVT i.YEAR i.AGEdi i.HPSEV2 i.FEMALE i.charlindex   , family(gamma) link(log)
margins , at((means) _all) dydx(PEDVT) // MARGINAL COSTS FOR COVARIATE
margins YEAR, at((means) _all) over(PEDVT) // MARGINAL COSTS FOR COVARIATE
marginsplot  , ylabel(0(5000)50000)   // MARGINSPLOT ONLY WORKS WITH STATA VERSION 12 OR HIGHER.


/* COMPLICATION - SAFETY OUTCOMES
THE FOLLOWING CODE SUMMARIZES RATES OF SAFETY COMPLICATIONS, COMBINING ALL YEARS. 
PATIENTS WITH EXCLUSIONS ARE REMOVED USING THE SVY SUBPOP COMMAND
INSTEAD OF RERUNNING THE COMMAND FOR EACH VARIABLE OF INTEREST, I SIMPLE LIST THE VARIABLES
ONE TIME IN A "local" (TEMPORARY STORAGE) VARIABLE CALL "covars" AND THEN LOOP THROUGH THE COMMAND.
LOOPING IS AN EFFICIENT WAY OF REPEATING A COMMAND WITH WRITING A LOT OF CODE.
 */ 
local covars = "HPPSI1 HPPSI2 HPPSI3 HPPSI4 HPPSI5 HPPSI6 HPPSI7 HPPSI8 HPPSI9 HPPSI10 HPPSI11 HPPSI12 HPPSI13 HPPSI14 "  // STORE LIST OF VARIABLES OF INTEREST AS COVARS
foreach v of local covars {											// LOOP THROUGH EACH VARIABLE IN COVAR
svy linearized, subpop(if ANYEX == 0) : mean `v'					// AND TEST DIFFERNCE IN FREQUENCY BETWEEN TWO YEARS
}


/* COMPLICATION - SAFETY OUTCOMES  - logistic regression 
THE FOLLOWING CODE PERFORMS A REGRESSION ANALYSIS TO IDENTIFY FACTORS ASSOCIATED WITH ANY COMPLICATION.
IN THE EXAMPLE DATASET, INDIVIDUAL COMPLICATIONS WERE EXTREMELY RARE IN THE LIMITED SAMPLE FOR EDUCATIONAL PURPOSES
TO MAKE THE COEFFICIENTS EASIER TO INTERPRET, "YEARre" IS GENERATED FROM YEAR WITH 2001 SET TO ZERO (REFERENCE)
AN INTERACTION TERM WAS INCLUDED TO DETERINE WHETHER THE RISK OF COMPLICATION WAS RISING FACTER AMONG THOSE OVER 65
PATIENTS WITH EXCLUSIONS ARE REMOVED USING THE SVY SUBPOP COMMAND
POSTESTIMATION MARGINAL EFFECTS ARE DERIVED USING STATA'S NEW MARGINS COMMAND. (MAY NOT BE AVAILABLE IN OLDER STATA
RACE WAS REMOVED IN THE MODEL DUE TO SMALL CELL COUNTS WHEN CROSS-TABULATED WITH THE OUTCOME.
 */ 
svy linearized , subpop(if ANYEX == 0 & YEAR > 2001) : glm ANYPSI i.YEAR#i.HPSEV2 i.AGEdi i.FEMALE   i.charlindex , eform family(binom) link(logit) // SURVEY GLM OF ANY COMPLICATIONS
margins  YEAR, at((mean) _all) over(HPSEV2)   // MARGINAL EFFECTS OF +/- AGE OVER 65  : THIS CAN SOMETIMES TAKE A LONG TIME IN BIG DATA SETS
marginsplot, ylabel(0(.05).25)   // MARGINSPLOT ONLY WORKS WITH STATA VERSION 12 OR HIGHER.

/*
IF YOU DON'T HAVE STATA VERSION 12 THEN MARGINSPLOT (ABOVE) WILL NOT WORK,  INSTEAD TRY THE CODE BELOW 
WHICH USED THE OLDER "ADJUST" COMMAND TO STORE AN ADJUSTED PREDICTION.
THIS CODE DRAWS A FIGURE OF THE MARGINAL RATES OVER TIME ADJUSTED FOR ALL OTHER COVARIATES IN MODEL
IT ALSO PLOTS THE RAW (OBSERVED RATES)
IN THIS EXAMPLE THERE IS A FAIRLY CLEAR EXAMPLE OF CONFOUNDING BY INDICATION AND THE EFFECT THAT ADJUSTING HAS.
TRY RUNNING THE ADJUSTMENT WITH AND WITHOUT THE COVARIATES FOR COMORBIDITY AND DIAGNOSTIC SEVERITY
*/

preserve 
xi: svy linearized , subpop(if ANYEX == 0): logistic ANYPSI i.YEAR i.AGEdi i.FEMALE i.charlindex i.HPSEV2 , or
adjust  _IFEMALE_1 _IHPSEV2_2 _IHPSEV2_3 _Icharlinde_1 _Icharlinde_2  , gen(model1) by(AGEdi YEAR) pr
collapse (mean) ANYPSI model1 [pw = DISCWTR] if ANYEX == 0, by(YEAR AGEdi)
twoway (lfit model1 YEAR if AGEdi == 0 , lc(black) lp(dash)) ///
(scatter model1 YEAR if AGEdi == 1, msymbol(O) lc(red)) ///
(scatter ANYPSI YEAR if AGEdi == 0, msymbol(sh) lc(black)) ///
(lfit model1 YEAR if AGEdi == 1 , lc(red)) ///
(scatter model1 YEAR if AGEdi == 0, msymbol(Oh) lc(black) ls(large)) ///
(scatter ANYPSI YEAR if AGEdi == 1, msymbol(s) lc(red)) 

restore

log close
exit


